@@ -1,5 +1,5 @@
 package Module::Build::Tiny;
-$Module::Build::Tiny::VERSION = '0.052';
+$Module::Build::Tiny::VERSION = '0.053';
 use strict;
 use warnings;
 use Exporter 5.57 'import';
@@ -141,6 +141,7 @@ my %actions = (
 			lib => [ map { rel2abs(catdir(qw/blib/, $_)) } qw/arch lib/ ],
 		);
 		my $tester = TAP::Harness::Env->create(\%test_args);
+		local $ENV{PERL_DL_NONLAZY} = 1;
 		return $tester->runtests(sort +find(qr/\.t$/, 't'))->has_errors;
 	},
 	install => sub {
@@ -191,16 +192,17 @@ sub Build_PL {
 	make_executable('Build');
 	my @env = defined $ENV{PERL_MB_OPT} ? split_like_shell($ENV{PERL_MB_OPT}) : ();
 	write_file('_build_params', encode_json([ \@env, \@ARGV ]));
+	my %mymeta = %{ $meta->as_struct };
 	if (my $dynamic = $meta->custom('x_dynamic_prereqs')) {
-		my %meta = (%{ $meta->as_struct }, dynamic_config => 0);
 		my %opt = get_arguments(\@env, \@ARGV);
 		require CPAN::Requirements::Dynamic;
 		my $dynamic_parser = CPAN::Requirements::Dynamic->new(%opt);
 		my $prereq = $dynamic_parser->evaluate($dynamic);
-		$meta{prereqs} = $meta->effective_prereqs->with_merged_prereqs($prereq)->as_string_hash;
-		$meta = CPAN::Meta->new(\%meta);
+		$mymeta{prereqs} = $meta->effective_prereqs->with_merged_prereqs($prereq)->as_string_hash;
 	}
-	$meta->save(@$_) for ['MYMETA.json'], [ 'MYMETA.yml' => { version => 1.4 } ];
+	$mymeta{dynamic_config} = 0;
+	my $mymeta = CPAN::Meta->new(\%mymeta);
+	$mymeta->save(@$_) for ['MYMETA.json'], [ 'MYMETA.yml' => { version => 1.4 } ];
 }
 
 1;
@@ -222,7 +224,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
